@@ -355,7 +355,7 @@ test_that("confint with mapped parameters", {
 
 
 test_that("profile", {
-    p1_th <- profile(fm1,parm="theta_",npts=4)
+    p1_th <- profile(fm1, parm="theta_", npts=4)
     expect_true(all(p1_th$.par=="theta_1|Subject.1"))
     p1_b <- profile(fm1,parm="beta_",npts=4)
     expect_equal(unique(as.character(p1_b$.par)),
@@ -613,3 +613,15 @@ test_that("trunc poisson simulation", {
         par(op)
     }
 })
+
+test_that("de novo simulation", {
+    dd <- data.frame(x = 1:10)
+    expect_error(simulate_new(y ~ x), "should take a one-sided")
+    ss <- simulate_new(~ x,
+                 seed = 101,
+                 family = gaussian,
+                 newdata = dd,
+                 newparams = list(beta = 1:2, betad = 0))
+    expect_equal(head(ss[[1]], 2),
+                      c(2.67396350948461, 5.55246185541914))
+})
